
# Changelog

## [Unreleased][]

[Unreleased]: https://github.com/chaostoolkit-incubator/chaostoolkit-gandi/compare/0.2.0...HEAD

# [0.2.0][]

[0.2.0]: https://github.com/chaostoolkit-incubator/chaostoolkit-gandi/compare/0.1.3...0.2.0

### Changed

- Modernize build pipeline

# [0.1.3][]

[0.1.3]: https://github.com/chaostoolkit-incubator/chaostoolkit-gandi/compare/0.1.2...0.1.3

### Changed

- Switched to GitHub actions
- Fix pinning of logzero dependency

# [0.1.2][]

[0.1.2]: https://github.com/chaostoolkit-incubator/chaostoolkit-gandi/compare/0.1.1...0.1.2

### Changed

-   Modified the `domains_should_not_expire_in` tolerance to check all domains
    expiry before failing and returns a boolean as a result


## [0.1.1][]

[0.1.1]: https://github.com/chaostoolkit-incubator/chaostoolkit-gandi/compare/0.1.0...0.1.1

### Added

-   Add `MANIFEST.in` to package some files in source distribution


## [0.1.0][]

[0.1.0]: https://github.com/chaostoolkit-incubator/chaostoolkit-gandi/tree/0.1.0

### Added

-   Initial release
